"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.commandsObject = void 0;
const tslib_1 = require("tslib");
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const enquirer = require("enquirer");
const path = require("path");
const tmp_1 = require("tmp");
const yargs = require("yargs");
const shared_1 = require("./shared");
const output_1 = require("./output");
const ora = require("ora");
const package_manager_1 = require("./package-manager");
const validate_npm_package_1 = require("./validate-npm-package");
const default_base_1 = require("./default-base");
const utils_1 = require("./utils");
const decorator_1 = require("./decorator");
const chalk = require("chalk");
const ci_1 = require("./ci");
const path_1 = require("path");
const git_1 = require("./git");
var Preset;
(function (Preset) {
    Preset["Apps"] = "apps";
    Preset["Empty"] = "empty";
    Preset["Core"] = "core";
    Preset["NPM"] = "npm";
    Preset["TS"] = "ts";
    Preset["WebComponents"] = "web-components";
    Preset["Angular"] = "angular";
    Preset["AngularWithNest"] = "angular-nest";
    Preset["React"] = "react";
    Preset["ReactWithExpress"] = "react-express";
    Preset["ReactNative"] = "react-native";
    Preset["NextJs"] = "next";
    Preset["Nest"] = "nest";
    Preset["Express"] = "express";
})(Preset || (Preset = {}));
const presetOptions = [
    {
        name: Preset.Apps,
        message: 'apps              [an empty workspace with no plugins with a layout that works best for building apps]',
    },
    {
        name: Preset.NPM,
        message: 'npm               [an empty workspace with no plugins set up to publish npm packages (similar to yarn workspaces)]',
    },
    {
        name: Preset.TS,
        message: 'ts                [an empty workspace with the JS/TS plugin preinstalled]',
    },
    {
        name: Preset.React,
        message: 'react             [a workspace with a single React application]',
    },
    {
        name: Preset.Angular,
        message: 'angular           [a workspace with a single Angular application]',
    },
    {
        name: Preset.NextJs,
        message: 'next.js           [a workspace with a single Next.js application]',
    },
    {
        name: Preset.Nest,
        message: 'nest              [a workspace with a single Nest application]',
    },
    {
        name: Preset.Express,
        message: 'express           [a workspace with a single Express application]',
    },
    {
        name: Preset.WebComponents,
        message: 'web components    [a workspace with a single app built using web components]',
    },
    {
        name: Preset.ReactNative,
        message: 'react-native      [a workspace with a single React Native application]',
    },
    {
        name: Preset.ReactWithExpress,
        message: 'react-express     [a workspace with a full stack application (React + Express)]',
    },
    {
        name: Preset.AngularWithNest,
        message: 'angular-nest      [a workspace with a full stack application (Angular + Nest)]',
    },
];
const nxVersion = require('../package.json').version;
const tsVersion = '~4.7.2'; // This gets replaced with the typescript version in the root package.json during build
const prettierVersion = '^2.6.2'; // This gets replaced with the prettier version in the root package.json during build
exports.commandsObject = yargs
    .wrap(yargs.terminalWidth())
    .parserConfiguration({
    'strip-dashed': true,
    'dot-notation': true,
})
    .command(
// this is the default and only command
'$0 [name] [options]', 'Create a new Nx workspace', (yargs) => yargs
    .option('name', {
    describe: chalk.dim `Workspace name (e.g. org name)`,
    type: 'string',
})
    .option('preset', {
    describe: chalk.dim `Customizes the initial content of your workspace. Default presets include: [${Object.values(Preset)
        .map((p) => `"${p}"`)
        .join(', ')}]. To build your own see https://nx.dev/packages/nx-plugin#preset`,
    type: 'string',
})
    .option('appName', {
    describe: chalk.dim `The name of the application when a preset with pregenerated app is selected`,
    type: 'string',
})
    .option('interactive', {
    describe: chalk.dim `Enable interactive mode with presets`,
    type: 'boolean',
})
    .option('cli', {
    describe: chalk.dim `CLI to power the Nx workspace`,
    choices: ['nx', 'angular'],
    type: 'string',
})
    .option('style', {
    describe: chalk.dim `Style option to be used when a preset with pregenerated app is selected`,
    type: 'string',
})
    .option('nxCloud', {
    describe: chalk.dim `Set up distributed caching using Nx Cloud (It's free and doesn't require registration.)`,
    type: 'boolean',
})
    .option('ci', {
    describe: chalk.dim `Generate a CI workflow file`,
    choices: ci_1.ciList,
    defaultDescription: '',
    type: 'string',
})
    .option('allPrompts', {
    alias: 'a',
    describe: chalk.dim `Show all prompts`,
    type: 'boolean',
    default: false,
})
    .option('packageManager', {
    alias: 'pm',
    describe: chalk.dim `Package manager to use`,
    choices: [...package_manager_1.packageManagerList].sort(),
    defaultDescription: 'npm',
    type: 'string',
})
    .option('defaultBase', {
    defaultDescription: 'main',
    describe: chalk.dim `Default base to use for new projects`,
    type: 'string',
})
    .option('skipGit', {
    describe: chalk.dim `Skip initializing a git repository.`,
    type: 'boolean',
    default: false,
    alias: 'g',
})
    .option('commit.name', {
    describe: chalk.dim `Name of the committer`,
    type: 'string',
})
    .option('commit.email', {
    describe: chalk.dim `E-mail of the committer`,
    type: 'string',
})
    .option('commit.message', {
    describe: chalk.dim `Commit message`,
    type: 'string',
    default: 'Initial commit',
}), (argv) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    yield main(argv).catch((error) => {
        const { version } = require('../package.json');
        output_1.output.error({
            title: `Something went wrong! v${version}`,
        });
        throw error;
    });
}), [getConfiguration])
    .help('help', chalk.dim `Show help`)
    .updateLocale(decorator_1.yargsDecorator)
    .version('version', chalk.dim `Show version`, nxVersion);
function main(parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { name, cli, preset, appName, style, nxCloud, packageManager, defaultBase, ci, skipGit, commit, } = parsedArgs;
        output_1.output.log({
            title: `Nx is creating your v${nxVersion} workspace.`,
            bodyLines: [
                'To make sure the command works reliably in all environments, and that the preset is applied correctly,',
                `Nx will run "${packageManager} install" several times. Please wait.`,
            ],
        });
        const tmpDir = yield createSandbox(packageManager);
        const directory = yield createApp(tmpDir, name, packageManager, Object.assign(Object.assign({}, parsedArgs), { cli,
            preset,
            appName,
            style,
            nxCloud,
            defaultBase }));
        let nxCloudInstallRes;
        if (nxCloud) {
            nxCloudInstallRes = yield setupNxCloud(name, packageManager);
        }
        if (ci) {
            yield setupCI(name, ci, packageManager, nxCloud && nxCloudInstallRes.code === 0);
        }
        if (!skipGit) {
            try {
                yield (0, git_1.initializeGitRepo)(directory, { defaultBase, commit });
            }
            catch (e) {
                output_1.output.error({
                    title: 'Could not initialize git repository',
                    bodyLines: [e.message],
                });
            }
        }
        (0, shared_1.showNxWarning)(name);
        pointToTutorialAndCourse(preset);
        if (nxCloud && nxCloudInstallRes.code === 0) {
            printNxCloudSuccessMessage(nxCloudInstallRes.stdout);
        }
    });
}
function getConfiguration(argv) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            let style, appName;
            const name = yield determineWorkspaceName(argv);
            let preset = yield determineThirdPartyPackage(argv);
            if (!preset) {
                preset = yield determinePreset(argv);
                appName = yield determineAppName(preset, argv);
                style = yield determineStyle(preset, argv);
            }
            const cli = yield determineCli(preset, argv);
            const packageManager = yield determinePackageManager(argv);
            const defaultBase = yield determineDefaultBase(argv);
            const nxCloud = yield determineNxCloud(argv);
            const ci = yield determineCI(argv, nxCloud);
            Object.assign(argv, {
                name,
                preset,
                appName,
                style,
                cli,
                nxCloud,
                packageManager,
                defaultBase,
                ci,
            });
        }
        catch (e) {
            console.error(e);
            process.exit(1);
        }
    });
}
function determineWorkspaceName(parsedArgs) {
    const workspaceName = parsedArgs._[0]
        ? parsedArgs._[0].toString()
        : parsedArgs.name;
    if (workspaceName) {
        return Promise.resolve(workspaceName);
    }
    return enquirer
        .prompt([
        {
            name: 'WorkspaceName',
            message: `Workspace name (e.g., org name)    `,
            type: 'input',
        },
    ])
        .then((a) => {
        if (!a.WorkspaceName) {
            output_1.output.error({
                title: 'Invalid workspace name',
                bodyLines: [`Workspace name cannot be empty`],
            });
            process.exit(1);
        }
        return a.WorkspaceName;
    });
}
function determinePackageManager(parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const packageManager = parsedArgs.packageManager;
        if (packageManager) {
            if (package_manager_1.packageManagerList.includes(packageManager)) {
                return Promise.resolve(packageManager);
            }
            output_1.output.error({
                title: 'Invalid package manager',
                bodyLines: [
                    `Package manager must be one of ${(0, utils_1.stringifyCollection)([
                        ...package_manager_1.packageManagerList,
                    ])}`,
                ],
            });
            process.exit(1);
        }
        if (parsedArgs.allPrompts) {
            return enquirer
                .prompt([
                {
                    name: 'PackageManager',
                    message: `Which package manager to use       `,
                    initial: 'npm',
                    type: 'autocomplete',
                    choices: [
                        { name: 'npm', message: 'NPM' },
                        { name: 'yarn', message: 'Yarn' },
                        { name: 'pnpm', message: 'PNPM' },
                    ],
                },
            ])
                .then((a) => a.PackageManager);
        }
        return Promise.resolve((0, package_manager_1.detectInvokedPackageManager)());
    });
}
function determineDefaultBase(parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (parsedArgs.defaultBase) {
            return Promise.resolve(parsedArgs.defaultBase);
        }
        if (parsedArgs.allPrompts) {
            return enquirer
                .prompt([
                {
                    name: 'DefaultBase',
                    message: `Main branch name                   `,
                    initial: `main`,
                    type: 'input',
                },
            ])
                .then((a) => {
                if (!a.DefaultBase) {
                    output_1.output.error({
                        title: 'Invalid branch name',
                        bodyLines: [`Branch name cannot be empty`],
                    });
                    process.exit(1);
                }
                return a.DefaultBase;
            });
        }
        return Promise.resolve((0, default_base_1.deduceDefaultBase)());
    });
}
function isKnownPreset(preset) {
    return Object.values(Preset).includes(preset);
}
function determineThirdPartyPackage({ preset, }) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (preset && !isKnownPreset(preset)) {
            const packageName = preset.match(/.+@/)
                ? preset[0] + preset.substring(1).split('@')[0]
                : preset;
            const validateResult = (0, validate_npm_package_1.validateNpmPackage)(packageName);
            if (validateResult.validForNewPackages) {
                return Promise.resolve(preset);
            }
            else {
                //! Error here
                output_1.output.error({
                    title: 'Invalid preset npm package',
                    bodyLines: [
                        `There was an error with the preset npm package you provided:`,
                        '',
                        ...validateResult.errors,
                    ],
                });
                process.exit(1);
            }
        }
        else {
            return Promise.resolve(null);
        }
    });
}
function determinePreset(parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (parsedArgs.preset) {
            if (Object.values(Preset).indexOf(parsedArgs.preset) === -1) {
                output_1.output.error({
                    title: 'Invalid preset',
                    bodyLines: [
                        `It must be one of the following:`,
                        '',
                        ...Object.values(Preset),
                    ],
                });
                process.exit(1);
            }
            else {
                return Promise.resolve(parsedArgs.preset);
            }
        }
        return enquirer
            .prompt([
            {
                name: 'Preset',
                message: `What to create in the new workspace`,
                initial: 'empty',
                type: 'autocomplete',
                choices: presetOptions,
            },
        ])
            .then((a) => a.Preset);
    });
}
function determineAppName(preset, parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (preset === Preset.Apps ||
            preset === Preset.Core ||
            preset === Preset.TS ||
            preset === Preset.Empty ||
            preset === Preset.NPM) {
            return Promise.resolve('');
        }
        if (parsedArgs.appName) {
            return Promise.resolve(parsedArgs.appName);
        }
        return enquirer
            .prompt([
            {
                name: 'AppName',
                message: `Application name                   `,
                type: 'input',
            },
        ])
            .then((a) => {
            if (!a.AppName) {
                output_1.output.error({
                    title: 'Invalid name',
                    bodyLines: [`Name cannot be empty`],
                });
                process.exit(1);
            }
            return a.AppName;
        });
    });
}
function isValidCli(cli) {
    return ['nx', 'angular'].indexOf(cli) !== -1;
}
function determineCli(preset, parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (parsedArgs.cli) {
            if (!isValidCli(parsedArgs.cli)) {
                output_1.output.error({
                    title: 'Invalid cli',
                    bodyLines: [`It must be one of the following:`, '', 'nx', 'angular'],
                });
                process.exit(1);
            }
            return Promise.resolve(parsedArgs.cli);
        }
        switch (preset) {
            case Preset.Angular:
            case Preset.AngularWithNest: {
                return Promise.resolve('angular');
            }
            default: {
                return Promise.resolve('nx');
            }
        }
    });
}
function determineStyle(preset, parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (preset === Preset.Apps ||
            preset === Preset.Core ||
            preset === Preset.TS ||
            preset === Preset.Empty ||
            preset === Preset.NPM ||
            preset === Preset.Nest ||
            preset === Preset.Express ||
            preset === Preset.ReactNative) {
            return Promise.resolve(null);
        }
        const choices = [
            {
                name: 'css',
                message: 'CSS',
            },
            {
                name: 'scss',
                message: 'SASS(.scss)       [ http://sass-lang.com   ]',
            },
            {
                name: 'less',
                message: 'LESS              [ http://lesscss.org     ]',
            },
        ];
        if (![Preset.Angular, Preset.AngularWithNest].includes(preset)) {
            choices.push({
                name: 'styl',
                message: 'Stylus(.styl)     [ http://stylus-lang.com ]',
            });
        }
        if ([Preset.ReactWithExpress, Preset.React, Preset.NextJs].includes(preset)) {
            choices.push({
                name: 'styled-components',
                message: 'styled-components [ https://styled-components.com            ]',
            }, {
                name: '@emotion/styled',
                message: 'emotion           [ https://emotion.sh                       ]',
            }, {
                name: 'styled-jsx',
                message: 'styled-jsx        [ https://www.npmjs.com/package/styled-jsx ]',
            });
        }
        if (!parsedArgs.style) {
            return enquirer
                .prompt([
                {
                    name: 'style',
                    message: `Default stylesheet format          `,
                    initial: 'css',
                    type: 'autocomplete',
                    choices: choices,
                },
            ])
                .then((a) => a.style);
        }
        const foundStyle = choices.find((choice) => choice.name === parsedArgs.style);
        if (foundStyle === undefined) {
            output_1.output.error({
                title: 'Invalid style',
                bodyLines: [
                    `It must be one of the following:`,
                    '',
                    ...choices.map((choice) => choice.name),
                ],
            });
            process.exit(1);
        }
        return Promise.resolve(parsedArgs.style);
    });
}
function determineNxCloud(parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (parsedArgs.nxCloud === undefined) {
            return enquirer
                .prompt([
                {
                    name: 'NxCloud',
                    message: `Set up distributed caching using Nx Cloud (It's free and doesn't require registration.)`,
                    type: 'autocomplete',
                    choices: [
                        {
                            name: 'Yes',
                            hint: 'Faster builds, run details, GitHub integration. Learn more at https://nx.app',
                        },
                        {
                            name: 'No',
                        },
                    ],
                    initial: 'Yes',
                },
            ])
                .then((a) => a.NxCloud === 'Yes');
        }
        else {
            return parsedArgs.nxCloud;
        }
    });
}
function determineCI(parsedArgs, nxCloud) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!nxCloud) {
            if (parsedArgs.ci) {
                output_1.output.warn({
                    title: 'Invalid CI value',
                    bodyLines: [
                        `CI option only works when Nx Cloud is enabled.`,
                        `The value provided will be ignored.`,
                    ],
                });
            }
            return '';
        }
        if (parsedArgs.ci) {
            return parsedArgs.ci;
        }
        if (parsedArgs.allPrompts) {
            return (enquirer
                .prompt([
                {
                    name: 'CI',
                    message: `CI workflow file to generate?      `,
                    type: 'autocomplete',
                    initial: '',
                    choices: [
                        { message: 'none', name: '' },
                        { message: 'GitHub Actions', name: 'github' },
                        { message: 'Circle CI', name: 'circleci' },
                        { message: 'Azure DevOps', name: 'azure' },
                    ],
                },
            ])
                // enquirer ignores name and value if they are falsy and takes
                // first field that has a truthy value, so wee need to explicitly
                // check for none
                .then((a) => (a.CI !== 'none' ? a.CI : '')));
        }
        return '';
    });
}
function createSandbox(packageManager) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const installSpinner = ora(`Installing dependencies with ${packageManager}`).start();
        const { install } = (0, package_manager_1.getPackageManagerCommand)(packageManager);
        const tmpDir = (0, tmp_1.dirSync)().name;
        try {
            (0, fs_1.writeFileSync)(path.join(tmpDir, 'package.json'), JSON.stringify({
                dependencies: {
                    '@nrwl/workspace': nxVersion,
                    nx: nxVersion,
                    typescript: tsVersion,
                    prettier: prettierVersion,
                },
                license: 'MIT',
            }));
            (0, package_manager_1.generatePackageManagerFiles)(tmpDir, packageManager);
            yield execAndWait(install, tmpDir);
            installSpinner.succeed();
        }
        catch (e) {
            installSpinner.fail();
            output_1.output.error({
                title: `Nx failed to install dependencies`,
                bodyLines: mapErrorToBodyLines(e),
            });
            process.exit(1);
        }
        finally {
            installSpinner.stop();
        }
        return tmpDir;
    });
}
function createApp(tmpDir, name, packageManager, parsedArgs) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { _, cli } = parsedArgs, restArgs = tslib_1.__rest(parsedArgs, ["_", "cli"]);
        // Ensure to use packageManager for args
        // if it's not already passed in from previous process
        if (!restArgs.packageManager) {
            restArgs.packageManager = packageManager;
        }
        const args = (0, shared_1.unparse)(restArgs).join(' ');
        const pmc = (0, package_manager_1.getPackageManagerCommand)(packageManager);
        const command = `new ${name} ${args} --collection=@nrwl/workspace/generators.json --cli=${cli}`;
        const workingDir = process.cwd().replace(/\\/g, '/');
        let nxWorkspaceRoot = `"${workingDir}"`;
        // If path contains spaces there is a problem in Windows for npm@6.
        // In this case we have to escape the wrapping quotes.
        if (process.platform === 'win32' &&
            /\s/.test(nxWorkspaceRoot) &&
            packageManager === 'npm') {
            const pmVersion = +(0, package_manager_1.getPackageManagerVersion)(packageManager).split('.')[0];
            if (pmVersion < 7) {
                nxWorkspaceRoot = `\\"${nxWorkspaceRoot.slice(1, -1)}\\"`;
            }
        }
        let workspaceSetupSpinner = ora('Creating your workspace').start();
        try {
            const fullCommand = `${pmc.exec} nx ${command} --nxWorkspaceRoot=${nxWorkspaceRoot}`;
            yield execAndWait(fullCommand, tmpDir);
            workspaceSetupSpinner.succeed('Nx has successfully created the workspace.');
        }
        catch (e) {
            workspaceSetupSpinner.fail();
            output_1.output.error({
                title: `Nx failed to create a workspace.`,
                bodyLines: mapErrorToBodyLines(e),
            });
            process.exit(1);
        }
        finally {
            workspaceSetupSpinner.stop();
        }
        return (0, path_1.join)(workingDir, name);
    });
}
function setupNxCloud(name, packageManager) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const nxCloudSpinner = ora(`Setting up NxCloud`).start();
        try {
            const pmc = (0, package_manager_1.getPackageManagerCommand)(packageManager);
            const res = yield execAndWait(`${pmc.exec} nx g @nrwl/nx-cloud:init --no-analytics --installationSource=create-nx-workspace`, path.join(process.cwd(), (0, utils_1.getFileName)(name)));
            nxCloudSpinner.succeed('NxCloud has been set up successfully');
            return res;
        }
        catch (e) {
            nxCloudSpinner.fail();
            output_1.output.error({
                title: `Nx failed to setup NxCloud`,
                bodyLines: mapErrorToBodyLines(e),
            });
            process.exit(1);
        }
        finally {
            nxCloudSpinner.stop();
        }
    });
}
function setupCI(name, ci, packageManager, nxCloudSuccessfullyInstalled) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!nxCloudSuccessfullyInstalled) {
            output_1.output.error({
                title: `CI workflow generation skipped`,
                bodyLines: [
                    `Nx Cloud was not installed`,
                    `The autogenerated CI workflow requires Nx Cloud to be set-up.`,
                ],
            });
        }
        const ciSpinner = ora(`Generating CI workflow`).start();
        try {
            const pmc = (0, package_manager_1.getPackageManagerCommand)(packageManager);
            const res = yield execAndWait(`${pmc.exec} nx g @nrwl/workspace:ci-workflow --ci=${ci}`, path.join(process.cwd(), (0, utils_1.getFileName)(name)));
            ciSpinner.succeed('CI workflow has been generated successfully');
            return res;
        }
        catch (e) {
            ciSpinner.fail();
            output_1.output.error({
                title: `Nx failed to generate CI workflow`,
                bodyLines: mapErrorToBodyLines(e),
            });
            process.exit(1);
        }
        finally {
            ciSpinner.stop();
        }
    });
}
function printNxCloudSuccessMessage(nxCloudOut) {
    const bodyLines = nxCloudOut.split('Nx Cloud has been enabled')[1].trim();
    output_1.output.note({
        title: `Nx Cloud has been enabled`,
        bodyLines: bodyLines.split('\n').map((r) => r.trim()),
    });
}
function mapErrorToBodyLines(error) {
    var _a;
    if (((_a = error.logMessage) === null || _a === void 0 ? void 0 : _a.split('\n').filter((line) => !!line).length) === 1) {
        // print entire log message only if it's only a single message
        return [`Error: ${error.logMessage}`];
    }
    const lines = [`Exit code: ${error.code}`, `Log file: ${error.logFile}`];
    if (process.env.NX_VERBOSE_LOGGING) {
        lines.push(`Error: ${error.logMessage}`);
    }
    return lines;
}
function execAndWait(command, cwd) {
    return new Promise((res, rej) => {
        (0, child_process_1.exec)(command, { cwd }, (error, stdout, stderr) => {
            if (error) {
                const logFile = path.join(cwd, 'error.log');
                (0, fs_1.writeFileSync)(logFile, `${stdout}\n${stderr}`);
                rej({ code: error.code, logFile, logMessage: stderr });
            }
            else {
                res({ code: 0, stdout });
            }
        });
    });
}
function pointToTutorialAndCourse(preset) {
    const title = `First time using Nx? Check out this interactive Nx tutorial.`;
    switch (preset) {
        case Preset.Empty:
        case Preset.NPM:
        case Preset.Apps:
        case Preset.Core:
            output_1.output.addVerticalSeparator();
            output_1.output.note({
                title,
                bodyLines: [`https://nx.dev/core-tutorial/01-create-blog`],
            });
            break;
        case Preset.TS:
            output_1.output.addVerticalSeparator();
            output_1.output.note({
                title,
                bodyLines: [`https://nx.dev/getting-started/nx-and-typescript`],
            });
            break;
        case Preset.React:
        case Preset.ReactWithExpress:
        case Preset.NextJs:
            output_1.output.addVerticalSeparator();
            output_1.output.note({
                title,
                bodyLines: [
                    `https://nx.dev/react-tutorial/01-create-application`,
                    ...pointToFreeCourseOnEgghead(),
                ],
            });
            break;
        case Preset.Angular:
        case Preset.AngularWithNest:
            output_1.output.addVerticalSeparator();
            output_1.output.note({
                title,
                bodyLines: [
                    `https://nx.dev/angular-tutorial/01-create-application`,
                    ...pointToFreeCourseOnYoutube(),
                ],
            });
            break;
        case Preset.Nest:
            output_1.output.addVerticalSeparator();
            output_1.output.note({
                title,
                bodyLines: [
                    `https://nx.dev/node-tutorial/01-create-application`,
                    ...pointToFreeCourseOnYoutube(),
                ],
            });
            break;
    }
}
function pointToFreeCourseOnYoutube() {
    return [
        ``,
        `Prefer watching videos? Check out this free Nx course on YouTube.`,
        `https://www.youtube.com/watch?v=2mYLe9Kp9VM&list=PLakNactNC1dH38AfqmwabvOszDmKriGco`,
    ];
}
function pointToFreeCourseOnEgghead() {
    return [
        ``,
        `Prefer watching videos? Check out this free Nx course on Egghead.io.`,
        `https://egghead.io/playlists/scale-react-development-with-nx-4038`,
    ];
}
//# sourceMappingURL=create-nx-workspace.js.map